mir.sre README
==============

.. image:: https://circleci.com/gh/darkfeline/mir.sre.svg?style=shield
   :target: https://circleci.com/gh/darkfeline/mir.sre
   :alt: CircleCI
.. image:: https://codecov.io/gh/darkfeline/mir.sre/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/darkfeline/mir.sre
   :alt: Codecov
.. image:: https://badge.fury.io/py/mir.sre.svg
   :target: https://badge.fury.io/py/mir.sre
   :alt: PyPI Release

Structural regular expressions for Python.
